@@ -156,9 +156,11 @@ void ProcessTableView::endProcess()
 {
     // no selected item, do nothing
     if (m_selectedPID.isNull()) {
+        qCDebug(app) << "No process selected for ending";
         return;
     }
 
+    qCDebug(app) << "Showing end process confirmation dialog for PID:" << m_selectedPID;
     // kill confirm dialog title & description
     QString title = DApplication::translate("Kill.Process.Dialog", "End process");
     QString description = DApplication::translate("Kill.Process.Dialog",
@@ -166,7 +168,6 @@ void ProcessTableView::endProcess()
                                                   "loss.\nAre you sure you want to continue?");
 
     KillProcessConfirmDialog dialog(this);
-    //    dialog.setTitle(title);
     dialog.setMessage(description);
     dialog.addButton(DApplication::translate("Kill.Process.Dialog", "Cancel", "button"), false);
     dialog.addButton(DApplication::translate("Kill.Process.Dialog", "End", "button"), true,
@@ -174,6 +175,7 @@ void ProcessTableView::endProcess()
     dialog.exec();
     if (dialog.result() == QMessageBox::Ok) {
         Process proc = m_model->getProcess(qvariant_cast<pid_t>(m_selectedPID));
+        qCDebug(app) << "User confirmed ending process:" << proc.name() << "(" << m_selectedPID << ")";
         QJsonObject obj {
             { "tid", EventLogUtils::ProcessKilled },
             { "version", QCoreApplication::applicationVersion() },
@@ -183,7 +185,7 @@ void ProcessTableView::endProcess()
 
         ProcessDB::instance()->endProcess(qvariant_cast<pid_t>(m_selectedPID));
     } else {
-        return;
+        qCDebug(app) << "User cancelled ending process:" << m_selectedPID;
     }
 }
 
@@ -193,8 +195,10 @@ void ProcessTableView::pauseProcess()
     auto pid = qvariant_cast<pid_t>(m_selectedPID);
     // no selected item or app self been selected, then do nothing
     if (m_selectedPID.isNull() || ProcessDB::instance()->isCurrentProcess(pid)) {
+        qCDebug(app) << "Cannot pause process - no selection or current process";
         return;
     }
+    qCDebug(app) << "Pausing process:" << pid;
     ProcessDB::instance()->pauseProcess(pid);
 }
 
@@ -204,9 +208,11 @@ void ProcessTableView::resumeProcess()
     auto pid = qvariant_cast<pid_t>(m_selectedPID);
     //no selected item or app self been selected, then do nothing
     if (m_selectedPID.isNull() || ProcessDB::instance()->isCurrentProcess(pid)) {
+        qCDebug(app) << "Cannot resume process - no selection or current process";
         return;
     }
 
+    qCDebug(app) << "Resuming process:" << pid;
     ProcessDB::instance()->resumeProcess(pid);
 }
 
@@ -219,9 +225,11 @@ void ProcessTableView::openExecDirWithFM()
         const Process &proc = ProcessDB::instance()->processSet()->getProcessById(pid);
         QString cmdline = proc.cmdlineString();
 
+        qCDebug(app) << "Opening exec directory for process:" << proc.name() << "(" << pid << ")";
         if (cmdline.size() > 0) {
             // Found wine program location if cmdline starts with c://.
             if (cmdline.startsWith("c:")) {
+                qCDebug(app) << "Found wine program, using wine prefix path";
                 QString winePrefix = proc.environ().value("WINEPREFIX");
                 cmdline = cmdline.replace("\\", "/").replace("c:/", "/drive_c/");
 
@@ -231,6 +239,7 @@ void ProcessTableView::openExecDirWithFM()
                 QString flatpakAppidEnv = proc.environ().value("FLATPAK_APPID");
                 // Else find program location through 'which' command.
                 if (flatpakAppidEnv == "") {
+                    qCDebug(app) << "Using which command to find program location";
                     QProcess whichProcess;
                     QString exec = "which";
                     QStringList params;
@@ -244,12 +253,14 @@ void ProcessTableView::openExecDirWithFM()
                         path = QString(output.split("\n")[0]).trimmed();
                         // 读取persistent目录
                         if (path.isEmpty()) {
+                            qCDebug(app) << "Path empty, checking namespace";
                             char nsPath[PATH_MAX] = { 0 }, nsSelfPath[PATH_MAX] = { 0 };
                             auto nsSize = readlink(QString("/proc/%1/ns/pid").arg(pid).toStdString().c_str(), nsPath, PATH_MAX);
                             auto nsSelfSize = readlink(QString("/proc/self/ns/pid").toStdString().c_str(), nsSelfPath, PATH_MAX);
                             if (nsSize > 0 && nsSelfSize > 0) {
                                 QString nsPathStr(nsPath), nsSelfPathStr(nsSelfPath);
                                 if (nsPathStr != nsSelfPathStr) {
+                                    qCDebug(app) << "Different namespace detected, searching for parent process";
                                     Process preProc = proc, curProc = proc;
                                     int count = 0;
                                     // 100次循环
@@ -260,6 +271,7 @@ void ProcessTableView::openExecDirWithFM()
                                     }
                                     if (curProc.pid() != 0 || count != 100) {
                                         pid = preProc.pid();
+                                        qCDebug(app) << "Found parent process:" << pid;
                                     }
                                     char exePath[PATH_MAX] = { 0 };
                                     auto exeSize = readlink(QString("/proc/%1/exe").arg(pid).toStdString().c_str(), exePath, PATH_MAX);
@@ -279,6 +291,7 @@ void ProcessTableView::openExecDirWithFM()
                                                     devStr = works[9];
                                                     if (!devStr.isEmpty()) {
                                                         path = "/persistent" + works[3] + exeStr.right(exeStr.size() - works[4].size());
+                                                        qCDebug(app) << "Found persistent path:" << path;
                                                     }
                                                     break;
                                                 }
@@ -296,6 +309,7 @@ void ProcessTableView::openExecDirWithFM()
                 }
                 // Find flatpak application location.
                 else {
+                    qCDebug(app) << "Found flatpak application, using flatpak info";
                     QProcess whichProcess;
                     QString exec = "flatpak";
                     QStringList params;
@@ -309,6 +323,7 @@ void ProcessTableView::openExecDirWithFM()
                     if (flatpakRootDir.cd("files") && flatpakRootDir.cd("bin")) {
                         // Need split full path to get last filename.
                         const QString &path = QString(flatpakRootDir.absoluteFilePath(cmdline.split("/").last())).trimmed();
+                        qCDebug(app) << "Found flatpak path:" << path;
                         common::openFilePathItem(path);
                     }
                 }
@@ -325,6 +340,7 @@ void ProcessTableView::showProperties()
         pid_t pid = qvariant_cast<pid_t>(m_selectedPID);
         // get process entry item from model
         auto proc = m_model->getProcess(pid);
+        qCDebug(app) << "Showing properties for process:" << proc.name() << "(" << pid << ")";
         auto *attr = new ProcessAttributeDialog(pid,
                                                 proc.name(),
                                                 proc.displayName(),
@@ -341,9 +357,11 @@ void ProcessTableView::killProcess()
 {
     // no selected item, do nothing
     if (m_selectedPID.isNull()) {
+        qCDebug(app) << "No process selected for killing";
         return;
     }
 
+    qCDebug(app) << "Showing kill process confirmation dialog for PID:" << m_selectedPID;
     // dialog
     QString title = DApplication::translate("Kill.Process.Dialog", "End process");
     QString description = DApplication::translate("Kill.Process.Dialog",
@@ -359,6 +377,7 @@ void ProcessTableView::killProcess()
     dialog.exec();
     if (dialog.result() == QMessageBox::Ok) {
         Process proc = m_model->getProcess(qvariant_cast<pid_t>(m_selectedPID));
+        qCDebug(app) << "User confirmed killing process:" << proc.name() << "(" << m_selectedPID << ")";
         QJsonObject obj {
             { "tid", EventLogUtils::ProcessKilled },
             { "version", QCoreApplication::applicationVersion() },
@@ -367,7 +386,7 @@ void ProcessTableView::killProcess()
         EventLogUtils::get().writeLogs(obj);
         ProcessDB::instance()->killProcess(qvariant_cast<pid_t>(m_selectedPID));
     } else {
-        return;
+        qCDebug(app) << "User cancelled killing process:" << m_selectedPID;
     }
 }
 
@@ -396,9 +415,12 @@ void ProcessTableView::changeProcessPriority(int priority)
 
         // if no changes in priority value, then do nothing
         auto prio = m_model->getProcessPriority(pid);
-        if (prio == priority)
+        if (prio == priority) {
+            qCDebug(app) << "Priority unchanged for process:" << pid;
             return;
+        }
 
+        qCDebug(app) << "Changing priority for process:" << pid << "from" << prio << "to" << priority;
         ProcessDB::instance()->setProcessPriority(pid, priority);
     }
 }
@@ -406,6 +428,7 @@ void ProcessTableView::changeProcessPriority(int priority)
 // load & restore table view settings from backup storage
 bool ProcessTableView::loadSettings(const QString &flag)
 {
+    qCDebug(app) << "Loading settings with flag:" << flag;
     Settings *s = Settings::instance();
     if (s) {
         const QVariant &opt = s->getOption(flag);
@@ -414,12 +437,15 @@ bool ProcessTableView::loadSettings(const QString &flag)
             const QByteArray &buf = QByteArray::fromBase64(opt.toByteArray());
             if (buf.endsWith(header_version)) {
                 header()->restoreState(buf);
+                qCDebug(app) << "Settings loaded successfully";
                 return true;
             } else {
+                qCWarning(app) << "Settings version mismatch";
                 return false;
             }
         }
     }
+    qCDebug(app) << "No settings found";
     return false;
 }
 
@@ -898,6 +924,7 @@ void ProcessTableView::initConnections(bool settingsLoaded)
     connect(ProcessDB::instance(), &ProcessDB::priorityPromoteResultReady, this,
             [=](const ErrorContext &ec) {
                 if (ec) {
+                    qCWarning(app) << "Failed to change priority:" << ec.getErrorName() << "-" << ec.getErrorMessage();
                     ErrorDialog::show(this, ec.getErrorName(), ec.getErrorMessage());
                 }
             });
@@ -908,8 +935,8 @@ void ProcessTableView::initConnections(bool settingsLoaded)
         m_pControlConnection = connect(ProcessDB::instance(), &ProcessDB::processControlResultReady, this,
                                        [=](const ErrorContext &ec) {
                                            if (ec) {
+                                               qCWarning(app) << "Process control failed:" << ec.getErrorName() << "-" << ec.getErrorMessage();
                                                ErrorDialog::show(this, ec.getErrorName(), ec.getErrorMessage());
-                                               qCWarning(app) << "ErrorName: " << ec.getErrorName() << ",ErrorMessage: " << ec.getErrorMessage();
                                            }
                                        });
 }
@@ -917,8 +944,10 @@ void ProcessTableView::initConnections(bool settingsLoaded)
 // show process table view context menu on specified positon
 void ProcessTableView::displayProcessTableContextMenu(const QPoint &p)
 {
-    if (selectedIndexes().size() == 0)
+    if (selectedIndexes().size() == 0) {
+        qCDebug(app) << "No process selected for context menu";
         return;
+    }
 
     QPoint point = mapToGlobal(p);
     point.setY(point.y() + header()->sizeHint().height());
@@ -1020,6 +1049,7 @@ void ProcessTableView::customizeProcessPriority()
         slider->setValue(selectedPriority);
         prio = QString("%1").arg(slider->value());
         slider->setTipValue(prio);
+        qCDebug(app) << "Setting initial priority value:" << selectedPriority << "for process:" << pid;
     }
     prioDialog->addContent(slider);
     prioDialog->addSpacing(16);
@@ -1032,9 +1062,11 @@ void ProcessTableView::customizeProcessPriority()
     connect(prioDialog, &DDialog::buttonClicked, this, [=](int index, QString text) {
         Q_UNUSED(text);
         if (index == 1) {
+            qCDebug(app) << "User confirmed priority change to:" << slider->value();
             changeProcessPriority(slider->value());
             prioDialog->setResult(QMessageBox::Ok);
         } else {
+            qCDebug(app) << "User cancelled priority change";
             prioDialog->setResult(QMessageBox::Cancel);
         }
     });
@@ -1044,6 +1076,7 @@ void ProcessTableView::customizeProcessPriority()
 void ProcessTableView::setUserModeName(const QString &userName)
 {
     if (userName != m_useModeName) {
+        qCDebug(app) << "Setting user mode name to:" << userName;
         m_useModeName = userName;
         m_model->setUserModeName(m_useModeName);
     }
